<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use \Cviebrock\EloquentSluggable\Sluggable;
use \Cviebrock\EloquentSluggable\SluggableScopeHelpers;

class City extends Model
{
    use Sluggable;
    use SluggableScopeHelpers;

    public $incrementing = false;

    public static function boot()
    {
        parent::boot();
        self::creating(function ($model) {
            $model->id = (string)\Uuid::generate();
        });
    }

    protected $fillable = [
        'name', 'country_id'
    ];

    public function sluggable()
    {
        return [
            'slug' => [
                'source' => 'name'
            ]
        ];
    }

    public function country(){
        return $this->belongsTo(Country::class);
    }

    public function city_histories(){ 
        return $this->hasMany(CityHistory::class);
    }

    public function getCoverAttribute($value){
        if($value){
            return asset(Config('app.storageUrl') . $value);
        } else {
            return asset("img/default-cover-route.jpg");
        }
    } 
}
