<?php
namespace App\Http\Controllers\Admin;

use App\Language;
use Illuminate\Http\Request;


class LanguageController extends Controller 
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $languages = Language::latest()->paginate(5);


        return $this->view('languages.index',compact('languages'))
            ->with('i', (request()->input('page', 1) - 1) * 5);
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return $this->view('languages.create');
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate([
            'name' => 'required',
        ]);


        Language::create($request->all());


        return redirect()->route('admin.languages.index')
                        ->with('success','Criado com sucesso.');
    }


    /**
     * Display the specified resource.
     *
     * @param  \App\Language  $language
     * @return \Illuminate\Http\Response
     */
    public function show(Language $language)
    {
        return $this->view('languages.show',compact('language'));
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Language  $language
     * @return \Illuminate\Http\Response
     */
    public function edit(Language $language)
    {
        return $this->view('languages.edit',compact('language'));
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Language  $language
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Language $language)
    {
         request()->validate([
            'name' => 'required',
        ]);


        $language->update($request->all());


        return redirect()->route('admin.languages.index')
                        ->with('success','Atualizado com sucesso');
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Language  $language
     * @return \Illuminate\Http\Response
     */
    public function destroy(Language $language)
    {
        $language->delete();


        return redirect()->route('admin.languages.index')
                        ->with('success','Deletado com sucesso');
    }
}