<?php
namespace App\Http\Controllers\Admin;

use App\Point as Ponto;
use App\Route;
use App\PointContent as ConteudoPonto;
use App\Language;
use App\RoutePoint;
use Illuminate\Http\Request;
use Storage;
use App\PointContent;

class PontoController extends Controller 
{
    /** 
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $pontos = Ponto::latest()->paginate(5);

        return $this->view('pontos.index',compact('pontos'))
            ->with('i', (request()->input('page', 1) - 1) * 5); 
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $rotas          =       Route::all();
        $languages      =       Language::all();

  

        $data = compact('rotas', 'languages');
        return $this->view('pontos.create',$data);
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $languages = Language::all();

        $ponto                      =           new Ponto;
        $ponto->name                =           $request->name;
        $ponto->address             =           $request->address;
        $ponto->latitude            =           $request->latitude;
        $ponto->longitude           =           $request->longitude;
        if($request->file('cover')){
            $ponto->cover               =           Storage::putFile('images/rota/cover', $request->file('cover'));  
        }
        $ponto->save();

        foreach($request->route_ids as $route_id){
            $obj                    =           new RoutePoint;
            $obj->route_id          =           $route_id;
            $obj->point_id          =           $ponto->id;
            $obj->save();
        }

        
        foreach ($languages as $language) {

            request()->validate([
                'text_message.' . $language->slug => 'required'
            ]);

            request()->validate([
                'audio_message.' . $language->slug => 'required'
            ]);

            $pointContent = ConteudoPonto::where('point_id', '=', $ponto->id)->where('language_id', '=', $language->id)->first();
            if (!$pointContent) {
                $pointContent = new ConteudoPonto;
            }
            if($request->file('audio_message.' . $language->slug)){
                $path = Storage::putFile('audio/point_content', $request->file('audio_message.' . $language->slug));
                $pointContent->audio_message = $path;
            }
            
            $pointContent->point_id = $ponto->id;
            $pointContent->language_id = $language->id;
            $pointContent->text_message = $request->text_message[$language->slug];
            
            $pointContent->save();
        }
        

        return redirect()->route('admin.pontos.edit', ['point_id' => $ponto->id])->with('success','Criado com sucesso');
    }


    /**
     * Display the specified resource.
     *
     * @param  \App\Ponto  $ponto
     * @return \Illuminate\Http\Response
     */
    public function show(Ponto $ponto)
    {
        return $this->view('pontos.show',compact('ponto'));
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Ponto  $ponto
     * @return \Illuminate\Http\Response
     */
    public function edit(Ponto $ponto)
    {
        $rotas          =       Route::all();
        $languages = Language::all();

        foreach ($languages as $language) {
            $language->content = ConteudoPonto::where('point_id', '=', $ponto->id)->where('language_id', '=', $language->id)->first();
        }

        $route_ids = $ponto->routes->pluck('id')->toArray();

        $data = compact('ponto', 'rotas', 'languages', 'route_ids');
        return $this->view('pontos.edit',$data);
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Ponto  $ponto
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Ponto $ponto)
    {

        foreach($ponto->route_points as $route_point){
            $route_point->delete();
        }

        foreach($request->route_ids as $route_id){
            $obj                    =           new RoutePoint;
            $obj->route_id          =           $route_id;
            $obj->point_id          =           $ponto->id;
            $obj->save();
        }

        $languages = Language::all();

        $ponto->name                =           $request->name;
        $ponto->address             =           $request->address;
        $ponto->latitude            =           $request->latitude;
        $ponto->longitude           =           $request->longitude;
        if($request->file('cover')){
            $ponto->cover               =           Storage::putFile('images/rota/cover', $request->file('cover'));  
        }
        $ponto->save();

        
        foreach ($languages as $language) {

            request()->validate([
                'text_message.' . $language->slug => 'required'
            ]);

            //request()->validate([
            //    'audio_message.' . $language->slug => 'required'
            //]);

            $pointContent = ConteudoPonto::where('point_id', '=', $ponto->id)->where('language_id', '=', $language->id)->first();
            if (!$pointContent) {
                $pointContent = new ConteudoPonto;
            }
            if($request->file('audio_message.' . $language->slug)){
                $path = Storage::putFile('audio/point_content', $request->file('audio_message.' . $language->slug));
                $pointContent->audio_message = $path;
            }
            
            $pointContent->point_id = $ponto->id;
            $pointContent->language_id = $language->id;
            $pointContent->text_message = $request->text_message[$language->slug];
            
            $pointContent->save();
        }
        

        return redirect()->route('admin.pontos.edit', ['point_id' => $ponto->id])->with('success','Atualizado com sucesso');
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Ponto  $ponto
     * @return \Illuminate\Http\Response
     */
    public function destroy(Ponto $ponto)
    {
        $routePoints = RoutePoint::where('point_id', '=', $ponto->id)->get();
        $pointContents = PointContent::where('point_id', '=', $ponto->id)->get();
      
        foreach($routePoints as $routePoint){
            $routePoint->delete();
        }

        foreach($pointContents as $pointContent){
            $pointContent->delete();
        }

        $ponto->delete();

        

        return redirect()->route('admin.pontos.index')
                        ->with('success','Deletado com sucesso');
    }
}