<?php
namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Route;
use App\RouteContent;
use App\Language;
use App\City;
use App\Point as Ponto;
use Storage;

class RotasController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rotas = Route::latest()->paginate(5);


        return $this->view('rotas.index', compact('rotas'))
            ->with('i', (request()->input('page', 1) - 1) * 5);
    }

    public function pontos(Request $request, $id)
    {  
        $pontos = Route::find($id)->points;

        return $this->view('rotas.pontos',compact('pontos'))
            ->with('i', (request()->input('page', 1) - 1) * 5);
    }

    public function pontos_update(Request $request, $id){
        $ponto          =           Ponto::find($id);
        $ponto->order   =           $request->order;
        $ponto->save();


        return response()->json($ponto);
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $languages = Language::all();

        $cidades            =           City::all();

        $data = compact('languages', 'cidades');

        return $this->view('rotas.create', $data);
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $languages = Language::all();

        $rota           =       new Route;
        $rota->city_id  =       $request->city_id;

        if($request->file('cover')){
            $rota->cover               =           Storage::putFile('images/rotas/cover', $request->file('cover'));
        }
        $rota->save(); 

        foreach ($languages as $language) {

            request()->validate([
                'name.' . $language->slug => 'required'
            ]);

            request()->validate([
                'description.' . $language->slug => 'required'
            ]);

            $routeContent = RouteContent::where('route_id', '=', $rota->id)->where('language_id', '=', $language->id)->first();
            if (!$routeContent) {
                $routeContent = new RouteContent;
            }

         
            $routeContent->route_id = $rota->id;
            $routeContent->language_id = $language->id;
            $routeContent->name = $request->name[$language->slug];
            $routeContent->description = $request->description[$language->slug];
            $routeContent->save();
        }

        return redirect()->route('admin.rotas.index') 
            ->with('success', 'Criado com sucesso');
    }


    /**
     * Display the specified resource.
     *
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function show(Historico $historico)
    {
        return $this->view('historicos.show', compact('historico'));
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request, $route_id)
    {
        $languages = Language::all();

        foreach ($languages as $language) {
            $language->data_historico = RouteContent::where('route_id', '=', $route_id)->where('language_id', '=', $language->id)->first(); 
        }

        $rota               =           Route::find($route_id);

        $cidades            =           City::all();

        $data = compact('languages', 'cidades', 'rota');

        return $this->view('rotas.edit', $data);
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $route_id)
    {

        $languages = Language::all();

        $rota           =       Route::find($route_id);
        $rota->city_id  =       $request->city_id;
        if($request->file('cover')){
            $rota->cover               =           Storage::putFile('images/rotas/cover', $request->file('cover'));
        }
        $rota->save();

        foreach ($languages as $language) {

            request()->validate([
                'name.' . $language->slug => 'required'
            ]);

            request()->validate([
                'description.' . $language->slug => 'required'
            ]);

            $routeContent = RouteContent::where('route_id', '=', $route_id)->where('language_id', '=', $language->id)->first();
            if (!$routeContent) {
                $routeContent = new RouteContent;
            }

         
            $routeContent->route_id = $route_id;
            $routeContent->language_id = $language->id;
            $routeContent->name = $request->name[$language->slug];
            $routeContent->description = $request->description[$language->slug];
            $routeContent->save();
        }

        return redirect()->route('admin.rotas.index') 
            ->with('success', 'Atualizado com sucesso');
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function destroy(Historico $historico)
    {
        $historico->delete();


        return redirect()->route('admin.historicos.index')
            ->with('success', 'Deletado com sucesso');
    }
}