<?php

namespace App\Http\Controllers\Api\Client;

use Illuminate\Http\Request;
use App\Http\Controllers\Api\Client\Controller;

use App\Transformers\Json;
use Illuminate\Foundation\Auth\SendsPasswordResetEmails;
use Illuminate\Support\Facades\Password;
use App\Notifications\ClientResetPassword;

use App\Client;
use Auth;
use Image;
use Storage;

class AuthController extends Controller
{
    use SendsPasswordResetEmails;

    public function __construct()
    {
        $this->middleware('guest');
    }

    public function resetarSenha(Request $request)
    {

        $this->validate($request, ['email' => 'required|email']);
        $client = Client::where('email', $request->input('email'))->first();

        if ($client) {
            $token = $this->broker('client')->createToken($client);
            $client->sendPasswordResetNotification($token);
        }
        
        return response()->json(['status' => 'success', 'message' => 'Se o email '.$request->email.' estiver associado a uma conta, você receberá em seu email instruções para resetar sua senha. <br><br> <strong>*Verifique sua caixa de spam ou lixeira</strong>']);
    }

    public function broker()
    {
        return Password::broker('clients');
    }

    
    public function validateToken(Request $request)
    {
        if($client = Client::where('token', '=', $request->token)->first()){
            return response()->json([
                'client'    => $client,
                'status'    => 'success',
                'message'   => 'The token is valid'
            ]);
        } else {
            return response()->json([
                'status' => 'error',
                'message' => 'Invalid token'
            ]);
        }
 
    }

    public function cadastro(Request $request){
        $response = array();

        $client = Client::where('email', '=', $request->email)->first();

        if(!$client){

            $name_array             =       explode(" ", $request->name);
            $first_name             =       $name_array["0"];
            unset($name_array["0"]);
            $last_name              =       implode(" ", $name_array);

            $client                 =       new Client;
            $client->name           =       $request->name;
            $client->country_id     =       $request->country_id;
            $client->language_id    =       \App\Language::where('slug', '=', $request->language_slug)->first()->id;
            $client->email          =       $request->email;
            $client->password       =       bcrypt($request->password); 
    
            if($avatar = upload_file('images/client/avatar/', $request->avatar, $base64 = true)){
                $client->avatar = $avatar;
            }

            $client->token      =       str_random(128);
            $client->save();

            $credentials = $request->only('email', 'password');
            $response['token']  = $client->token;
            $response['client'] = $client;

            return response()->json($response);

        } else {
            return response()->json(['error' => 'email_exists'], 401);
        }

        
    }

    public function login(Request $request){
        $response = array();

        if (Auth::guard('client')->attempt(['email' => $request->email, 'password' => $request->password])) {
            if(!$client = Client::where('email', '=', $request->email)->first()){
                return response()->json(['error' => 'invalid_token'], 401);
            }
            //$client->token = str_random(128);
            $client->save();
            $response['client'] = $client;
            $response['token']  = $client->token;
        } else {
            return response()->json(['error' => 'invalid_credentials'], 401);
        }

        return response()->json($response);
    }
}