<?php

namespace App\Http\Controllers\Api;

use Illuminate\Http\Request;
use App\Language;
use App\Country;
use App\WelcomeMessage;
use App\Route;
use App\City;
use App\CityHistory;
use App\Point;
use DB;

class DefaultController extends Controller
{
    public function getLang(){
        return Language::all();
    }
    public function getCountry(){
        return Country::all();
    }
    public function getWelcomeMessage(Request $request){
        $language = Language::where('slug', '=', $request->language_slug)->first();
        return WelcomeMessage::where('language_id', '=', $language->id)->first();
    }

    public function getRoutes(Request $request){
        $language = Language::where('slug', '=', $request->language_slug)->first();

        $response = Route::whereHas('city', function($query) use($request){
            $query->where('name', '=', $request->cidade);
        })->with('city')->with('route_contents')->get();

        if($response){
            foreach($response as $route){
                foreach($route->route_contents as $content){
                    if($content->language_id == $language->id){
                        $route->translated_content = $content;
                    }
                }
                unset($route->route_contents);
            }
        }

        return $response;
    }

    public function getCityHistory(Request $request){
        $language   = Language::where('slug', '=', $request->language_slug)->first();
        $city       = City::where('name', '=', $request->cidade)->first();

        $response = CityHistory::where('language_id', '=', $language->id)->where('city_id', '=', $city->id)->first();

        return $response;
    }

    public function getCity(Request $request){
        $response = City::where('name', '=', $request->cidade)->first();

        return $response;
    }

    public function getCities(){
        $response = City::all();

        return $response;
    }

    public function getPointById(Request $request){
        $language = Language::where('slug', '=', $request->language_slug)->first();

        $point      =       Point::find($request->point_id);

        if($point){
            foreach($point->point_contents as $content){
                if($content->language_id == $language->id){
                    $point->translated_content = $content;
                }
            }
            unset($point->point_contents);
        }


        return $point;
    }

    public function getPoints(Request $request){
        $language = Language::where('slug', '=', $request->language_slug)->first();

        $route      =       Route::find($request->route_id);

        $radius = 999999999999;
        $response  = Point::select(
            DB::raw("*,
                        ( 6371 * acos( cos( radians(" . $request->latitude . ") ) *
                        cos( radians( latitude ) )
                        * cos( radians( longitude ) - radians(" . $request->longitude . ")
                        ) + sin( radians(" . $request->latitude . ") ) *
                        sin( radians( latitude ) ) )
                        ) AS distance")
        )
            ->having("distance", "<", $radius)
            ->orderBy('order', "ASC")
            ->whereIn('id', $route->points->pluck('id')->toArray())
            ->with('point_contents')
            ->get();

        if($response){
            foreach($response as $point){
                foreach($point->point_contents as $content){
                    if($content->language_id == $language->id){
                        $point->translated_content = $content;
                    }
                }
                unset($point->point_contents);
            }
        }


        return $response;
    }
}
